@@ -412,7 +412,7 @@ PROT_ListManager.prototype.makeUpdateRequest_ = function(tableData) {
   // For each requested table that didn't have chunk data in the database,
   // request it fresh
   for (var tableName in tableNames) {
-    request += tableName + ";:mac\n";
+    request += tableName + ";mac\n";
   }
 
   G_Debug(this, 'checkForUpdates: scheduling request..');
